@@ -33,7 +33,7 @@ use constant FAKE_NO_NET_DNS => 0;    # for debugging only
 use constant FAKE_NO_NET_DOMAIN => 0; # for debugging only
 use constant FAKE_NO_MAIL_SEND => 0;  # for debugging only
 
-$VERSION = '1.5202';
+$VERSION = '1.5203';
 
 local $^W = 1;
 
@@ -156,7 +156,7 @@ sub report {
     my $report;
     $report .= "This distribution has been tested as part of the cpan-testers\n";
     $report .= "effort to test as many new uploads to CPAN as possible.  See\n";
-    $report .= "http://testers.cpan.org/\n\n";
+    $report .= "http://www.cpantesters.org/\n\n";
 
     if (not $self->{_comments}) {
         $report .= "\n\n--\n\n";
@@ -753,14 +753,10 @@ further information visit the below links:
 
 =over 4
 
-=item * L<http://cpantesters.perl.org/>
+=item * L<http://www.cpantesters.org/>
 
 CPAN Testers reports (new site)
 
-=item * L<http://testers.cpan.org/>
-
-CPAN Testers reports (old site)
-
 =item * L<http://cpantest.grango.org/>
 
 The new CPAN Testers Wiki (thanks Barbie!)
